@@ -1,21 +1,23 @@
 from django.db import models
 from wagtail.search import index
 from wagtail.admin.edit_handlers import FieldPanel
-from wagtail.documents.models import Document
 from wagtail.documents.edit_handlers import DocumentChooserPanel
 
+from webspace.cms.models import MyDocument
+from webspace.loader import get_model
+
 
 class AIconSnippet(index.Indexed, models.Model):
     key = models.CharField(max_length=255)
     light = models.ForeignKey(
-        Document,
+        MyDocument,
         null=True,
         blank=True,
         on_delete=models.SET_NULL,
         related_name='+',
     )
     space = models.ForeignKey(
-        Document,
+        MyDocument,
         null=True,
         blank=True,
         on_delete=models.SET_NULL,
@@ -35,6 +37,18 @@ class AIconSnippet(index.Indexed, models.Model):
     def __str__(self):
         return self.key
 
+    @staticmethod
+    def get_context():
+        IconSnippet = get_model('cms', 'IconSnippet')
+        ret = {}
+        DEFAULT_LINK = '/static/webspace/img/svg/default.svg'
+        for icon in IconSnippet.objects.all():
+            ret[icon.key] = {
+                'space': icon.space.url if icon.space else DEFAULT_LINK,
+                'light': icon.light.url if icon.light else DEFAULT_LINK,
+            }
+        return ret
+
     class Meta:
         verbose_name = "Icon"
         abstract = True
